@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: hakyll
 version: 4.7.5.2
-id: hakyll-4.7.5.2-e854ee49855603154159fa29193140c8
-key: hakyl_K4KZEhBVf4Y6tHFF4ISafp
+id: hakyll-4.7.5.2-ba728cb9e3fb7b271442b4c40e626b6f
+key: hakyl_30dzJhqAvkgBPT59Xfhubg
 license: BSD3
 maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
 homepage: http://jaspervdj.be/hakyll
@@ -50,7 +50,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/hakyll-4.7.5.2
-hs-libraries: HShakyll-4.7.5.2-K4KZEhBVf4Y6tHFF4ISafp
+hs-libraries: HShakyll-4.7.5.2-30dzJhqAvkgBPT59Xfhubg
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
@@ -71,7 +71,7 @@ depends:
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
     pandoc-1.17.0.3-257df634e15a54e32a712d876ce77ba5
-    pandoc-citeproc-0.9.1.1-26de2ff2cab65872a11f6945922d6e10
+    pandoc-citeproc-0.9.1.1-1b097fc52b987e4e8df58ce101963d64
     parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
